return {
    "nvim-lualine/lualine.nvim",
    dependencies = {
        "nvim-tree/nvim-web-devicons",
        "letieu/harpoon-lualine",
    },
    config = function()
        local lualine = require("lualine")
        local lazy_status = require("lazy.status")

		local function macro_recording()
			local recording_register = vim.fn.reg_recording()
			if recording_register == "" then
				return ""
			else
				return "Recording @" .. recording_register
			end
		end

        lualine.setup({
            options = {
                theme = "kanagawa",
                component_separators = { left = "", right = "" },
                section_separators = { left = "", right = "" },
                globalstatus = true,
            },
            extensions = {
                "fugitive",
                "oil",
                "quickfix",
            },
            sections = {
                lualine_b = {
                    { "branch" },
                    { "diff" },
                    { "diagnostics" },
                    {
                        function()
                            local buffers = vim.fn.getbufinfo({ buflisted = true })
                            return "Buffers: " .. #buffers
                        end,
                    },
                },
                lualine_c = {
                    { "filename", file_status = true, path = 1 },
                    { "harpoon2" },
					{ macro_recording, color = { fg = "#ff9e64", gui = "bold" } },
                },
                lualine_x = {
                    {
                        lazy_status.updates,
                        cond = lazy_status.has_updates,
                        color = { fg = "#ff9e64" },
                    },
                    { "fileformat" },
                    { "filetype" },
                },
                lualine_y = {
                    { "progress" },
                },
                lualine_z = {
                    { "location" }
                },
            },
        })
    end,
}
